==> qt-creator-2.6.2-src.tar.gz: qt-creator-2.6.2-src/src/plugins/qmljstools/qmljstoolssettings.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLJSTOOLSSETTINGS_H
#define QMLJSTOOLSSETTINGS_H

#include "qmljstools_global.h"

#include <QObject>

namespace TextEditor
{
class SimpleCodeStylePreferences;
}

namespace QmlJSTools
{

namespace Internal
{
class QmlJSToolsSettingsPrivate;
}

/**
 * This class provides a central place for cpp tools settings.
 */
class QMLJSTOOLS_EXPORT QmlJSToolsSettings : public QObject
{
    Q_OBJECT

public:
    explicit QmlJSToolsSettings(QObject *parent);
    ~QmlJSToolsSettings();

    static QmlJSToolsSettings *instance();

    TextEditor::SimpleCodeStylePreferences *qmlJSCodeStyle() const;

private:
    Internal::QmlJSToolsSettingsPrivate *d;

    static QmlJSToolsSettings *m_instance;
};

} // namespace QmlJSTools

#endif // QMLJSTOOLSSETTINGS_H

==> qt-creator-2.7.2-src.tar.gz: qt-creator-2.7.2-src/src/plugins/qmljstools/qmljstoolssettings.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLJSTOOLSSETTINGS_H
#define QMLJSTOOLSSETTINGS_H

#include "qmljstools_global.h"

#include <QObject>

namespace TextEditor { class SimpleCodeStylePreferences; }

namespace QmlJSTools {

/**
 * This class provides a central place for cpp tools settings.
 */
class QMLJSTOOLS_EXPORT QmlJSToolsSettings : public QObject
{
    Q_OBJECT

public:
    explicit QmlJSToolsSettings(QObject *parent);
    ~QmlJSToolsSettings();

    static TextEditor::SimpleCodeStylePreferences *globalCodeStyle();
};

} // namespace QmlJSTools

#endif // QMLJSTOOLSSETTINGS_H
